use crate::db::{Dao, TenebrousDbConn};
use crate::errors::Error;
use crate::models::{characters::CharacterEntry, users::User};
use rocket::response::Redirect;
use rocket_contrib::templates::Template;
use serde_derive::Serialize;

pub fn routes() -> Vec<rocket::Route> {
    routes![index, user_index]
}

/// Information to display to the user on their home page.
#[derive(Serialize)]
pub struct UserHomeContext<'a> {
    pub characters: &'a [CharacterEntry],
    pub user: &'a User,
}

#[get("/")]
fn user_index(user: &User, conn: TenebrousDbConn) -> Result<Template, Error> {
    let characters = conn.load_character_list(user.id)?;

    let context = UserHomeContext {
        characters: &characters,
        user: user,
    };

    Ok(Template::render("index", &context))
}

#[get("/", rank = 2)]
fn index() -> Redirect {
    super::common::redirect_to_login()
}
